@@ -1,15 +1,14 @@
-
 import logging
 
-from django.core.management.base import NoArgsCommand
+from django.core.management.base import BaseCommand
 
 from notification.engine import send_all
 
-class Command(NoArgsCommand):
+
+class Command(BaseCommand):
     help = "Emit queued notices."
     
-    def handle_noargs(self, **options):
+    def handle(self, *args, **options):
         logging.basicConfig(level=logging.DEBUG, format="%(message)s")
         logging.info("-" * 72)
-        send_all()
-    
\ No newline at end of file
+        send_all(*args)
