@@ -50,12 +50,12 @@ def notice_settings(request):
         next_page = request.POST.get("next_page", ".")
         return HttpResponseRedirect(next_page)
     
-    notice_settings = {
+    settings = {
         "column_headers": [medium_display for medium_id, medium_display in NOTICE_MEDIA],
         "rows": settings_table,
     }
     
     return render_to_response("notification/notice_settings.html", {
         "notice_types": notice_types,
-        "notice_settings": notice_settings,
+        "notice_settings": settings,
     }, context_instance=RequestContext(request))
